@@ -4,7 +4,6 @@ from policyengine_canada.model_api import *
 class maternity_and_parental_benefit(Variable):
     value_type = float
     entity = Person
-    label = "Maternity and Parental benefit"
+    label = "Employment Insurance maternity and parental benefits"
     unit = CAD
-    documentation = "Income from maternity and parental benefits"
     definition_period = YEAR
