@@ -8,10 +8,9 @@ class ab_income_tax_before_credits(Variable):
     unit = CAD
     definition_period = YEAR
     reference = "https://www.canada.ca/en/revenue-agency/services/tax/individuals/frequently-asked-questions-individuals/canadian-income-tax-rates-individuals-current-previous-years.html"
+    defined_for = ProvinceCode.AB
 
     def formula(person, period, parameters):
-        province = person.household("province", period)
-        in_alberta = province == province.possible_values.ALBERTA
         income = person("ab_taxable_income", period)
         p = parameters(period).gov.provinces.ab.tax.income.rate
-        return in_alberta * p.calc(income)
+        return p.calc(income)
