@@ -4,8 +4,7 @@ from policyengine_canada.model_api import *
 class bc_benefits(Variable):
     value_type = float
     entity = Household
-    label = "BC benefits"
-    documentation = "British Columbia benefits"
+    label = "British Columbia benefits"
     unit = CAD
     definition_period = YEAR
     defined_for = ProvinceCode.BC
