@@ -8,12 +8,9 @@ class nt_income_tax_before_credits(Variable):
     unit = CAD
     definition_period = YEAR
     reference = "https://www.canada.ca/en/revenue-agency/services/tax/individuals/frequently-asked-questions-individuals/canadian-income-tax-rates-individuals-current-previous-years.html"
+    defined_for = ProvinceCode.NT
 
     def formula(person, period, parameters):
-        province = person.household("province", period)
-        in_northwest_territories = (
-            province == province.possible_values.NORTHWEST_TERRITORIES
-        )
         income = person("nt_taxable_income", period)
         p = parameters(period).gov.provinces.nt.tax.income.rate
-        return in_northwest_territories * p.calc(income)
+        return p.calc(income)
